# 📇 Glossary

```{glossary}
Multiple-Dispatch
  Multiple dispatch is a programming paradigm in which the method or function to be called is determined by the runtime types of the arguments.
  This allows for  flexible and extensible code, as different implementations can be provided for different types of arguments.
  See [Wikipedia](https://en.wikipedia.org/wiki/Multiple_dispatch) for more information.

```
